pub struct ResolutionCache { /* private fields */ }Expand description
Service resolution cache for frequently accessed services
Caches resolved service instances to avoid repeated resolution overhead. Particularly beneficial for complex dependency graphs with deep nesting.
Implementations
Sourceimpl ResolutionCache
impl ResolutionCache
Sourcepub fn with_config(config: CacheConfig) -> Self
pub fn with_config(config: CacheConfig) -> Self
Create a new resolution cache with custom configuration
Sourcepub fn get(&self, key: &Key) -> Option<Arc<dyn Any + Send + Sync>>
pub fn get(&self, key: &Key) -> Option<Arc<dyn Any + Send + Sync>>
Get a service from the cache
Sourcepub fn put(&self, key: Key, service: Arc<dyn Any + Send + Sync>) -> DiResult<()>
pub fn put(&self, key: Key, service: Arc<dyn Any + Send + Sync>) -> DiResult<()>
Put a service into the cache
Sourcepub fn stats(&self) -> CacheStats
pub fn stats(&self) -> CacheStats
Get cache statistics